@@ -47,6 +47,7 @@ from ..workflows.upload_keys import upload_keys
 from ..protocols import Protocol, parse_protocol, __all__ as available_protocols, sftp
 from ..core.versioncheck import check_version
 from ..core.error import UserError
+from ..core.filesystem import OutOfSpaceError
 from .. import URL_READTHEDOCS, URL_GITLAB_ISSUES
 
 logger = create_logger(__name__)
@@ -118,15 +119,18 @@ def encrypt(
         )
     else:
         kwargs["passphrase"] = None
-    return workflows_encrypt(
-        *args,
-        dtr_id=dtr_id,
-        offline=offline,
-        verify_dtr=verify_dtr,
-        config=config,
-        dry_run=dry_run,
-        **kwargs,
-    )
+    try:
+        return workflows_encrypt(
+            *args,
+            dtr_id=dtr_id,
+            offline=offline,
+            verify_dtr=verify_dtr,
+            config=config,
+            dry_run=dry_run,
+            **kwargs,
+        )
+    except OutOfSpaceError as e:
+        raise OutOfSpaceError(f"{e} Use --force or -f to ignore this error.") from e
 
 
 @wraps(workflows_decrypt)
@@ -250,6 +254,9 @@ class Cli(Subcommands):
                     help="Purpose of the DTR (PRODUCTION, TEST). "
                     "Mandatory only if `transfer_id` is specified."
                 ),
+                "force": dict(
+                    help="Ignore errors about missing disk space", alias="-f"
+                ),
                 "output": dict(
                     help="output path (file or directory) to the "
                     "encrypted package. If no path is specified, "
