@@ -3,7 +3,7 @@ import io
 import re
 import urllib
 import warnings
-from typing import List, Optional, Tuple, Union, Type, IO, Callable, cast
+from typing import Iterable, List, Optional, Tuple, Union, Type, IO, Callable, cast
 from functools import wraps, partial
 
 import gpg_lite as gpg
@@ -130,17 +130,58 @@ def detach_sign_file(
         raise UserError(f"File signing failed. {e}") from e
 
 
-def check_password(user_fingerprint: str, passphrase: str, gpg_store: GPGStore):
-    """Check if key password is correct"""
+def enforce_passphrase(passphrase: Optional[Secret]) -> Secret:
+    """Verify that a passphrase is not empty, and return it"""
+    if passphrase is None:
+        raise ValueError("No password given")
+    return passphrase
+
+
+def check_password(password: Secret, key_fingerprint: str, gpg_store: GPGStore):
+    """Verify that the provided password matches the specified PGP key.
+
+    The verification is done by trying to use the key specified via its
+    fingerprint to sign some mock data. If this opperation fails, the password
+    is incorrect and an error is raised.
+    """
     try:
         with gpg_store.detach_sig(
-            src=b"test", passphrase=passphrase, signee=user_fingerprint
+            src=b"test", passphrase=password, signee=key_fingerprint
         ):
             pass
     except gpg.cmd.GPGError:
         raise UserError("GPG password is incorrect") from None
 
 
+def check_password_matches_any_key(
+    password: Secret, keys: Iterable[gpg.Key], gpg_store: GPGStore
+) -> None:
+    """Check whether a password matches any of the provided GPG keys.
+
+    If the password does not match with any of the keys, an error is raised.
+
+    :param keys: list of GPG keys to check.
+    :password: password to check against the different keys.
+    :gpg_store: GnuPG database containing the keys to check.
+    :raises UserError:
+    """
+    for key in keys:
+        try:
+            check_password(
+                password=password,
+                key_fingerprint=key.fingerprint,
+                gpg_store=gpg_store,
+            )
+            break
+        except UserError:
+            pass
+    else:
+        raise UserError(
+            "The provided password does not match any of the GPG keys with "
+            "which the data was encrypted"
+        )
+
+
 class KeyType(enum.Enum):
     public = enum.auto()
     secret = enum.auto()
