@@ -4,7 +4,7 @@ import warnings
 from contextlib import contextmanager
 from itertools import count
 from pathlib import Path
-from typing import List, Iterator, Union
+from typing import List, Iterator, Union, Sequence
 
 from .error import UserError
 from ..utils.log import create_logger
@@ -116,3 +116,17 @@ def delete_file_on_error(path: Union[str, Path]):
         else:
             logger.debug("File doesn't exist: %s", path)
         raise e
+
+
+class OutOfSpaceError(UserError):
+    """UserError version of OSError(28, "No space left on device")"""
+
+
+def check_space(files: Sequence[str], dest: str, force: bool = False):
+    required_space = sum(os.path.getsize(path) for path in files)
+    available_space = shutil.disk_usage(dest).free
+    if required_space >= available_space:
+        msg = f"No space left on device\nrequired: {required_space}, available: {available_space}."
+        if not force:
+            raise OutOfSpaceError(msg)
+        warnings.warn(msg + " Operation will most likely fail.")
