@@ -1,11 +1,11 @@
-from functools import partial
+from functools import partial, wraps
 
 from .component import (
     TabMixin,
     PathInput,
     GuiProgress,
     create_slider,
-    run_dialog,
+    get_text_input,
     SelectionButton,
     MandatoryLabel,
     create_verify_dtr_checkbox,
@@ -17,10 +17,24 @@ from .parallel import Worker
 from .pyside import QtCore, QtGui, QtWidgets
 from .settings_tab import LABEL_COMPRESSION_LEVEL, STATUS_TIP_COMPRESSION_LEVEL
 from ..core.metadata import Purpose
+from ..core.filesystem import OutOfSpaceError
 from ..utils.validation import PACKAGE_SUFFIX
 from ..workflows import encrypt
 
 
+ignore_disk_space_error_label = "Ignore disk space error"
+
+
+@wraps(encrypt.encrypt)
+def encrypt_workflow(*args, **kwargs):
+    try:
+        encrypt.encrypt(*args, **kwargs)
+    except OutOfSpaceError as e:
+        raise OutOfSpaceError(
+            f"{e} Use the checkbox '{ignore_disk_space_error_label}' in the output box to ignore this error.",
+        ) from e
+
+
 class EncryptTab(QtWidgets.QWidget, TabMixin):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -189,6 +203,23 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
         for w in (QtWidgets.QLabel(LABEL_COMPRESSION_LEVEL),) + slider_widgets:
             compression_layout.addWidget(w)
 
+        ignore_disk_space_error = QtWidgets.QCheckBox(
+            ignore_disk_space_error_label, group_box
+        )
+        ignore_disk_space_error.setStatusTip(
+            "Write to disk, even if there is less space available than the input data occupies."
+        )
+        ignore_disk_space_error.setChecked(
+            self.app_data.encrypt_ignore_disk_space_error
+        )
+        ignore_disk_space_error.stateChanged.connect(
+            lambda state: setattr(
+                self.app_data,
+                "encrypt_ignore_disk_space_error",
+                state == QtCore.Qt.Checked,
+            )
+        )
+
         layout = QtWidgets.QGridLayout(group_box)
         layout.addWidget(QtWidgets.QLabel("Suffix"), 0, 0, 1, 1)
         layout.addWidget(output_suffix, 0, 1, 1, 1)
@@ -196,6 +227,7 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
         layout.addWidget(output_location.text, 1, 1, 1, 1)
         layout.addWidget(output_location.btn, 1, 2, 1, 1)
         layout.addLayout(compression_layout, 2, 0, 1, 2)
+        layout.addWidget(ignore_disk_space_error, 3, 0, 1, 2)
         return group_box
 
     def _create_metadata_group_box(self):
@@ -234,13 +266,13 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
         progress = GuiProgress()
         progress.updated.connect(self.progress_bar.setValue)
         if not dry_run and self.app_data.config.sign_encrypted_data:
-            pw = run_dialog(self, "Enter password for your GPG key")
+            pw = get_text_input(self, "Enter password for your GPG key")
             if pw is None:
                 return
         else:
             pw = None
         worker = Worker(
-            encrypt.encrypt,
+            encrypt_workflow,
             self.app_data.encrypt_files,
             capture_loggers=(encrypt.logger,),
             sender=self.app_data.encrypt_sender,
@@ -258,6 +290,7 @@ class EncryptTab(QtWidgets.QWidget, TabMixin):
             progress=progress,
             ignore_exceptions=True,
             report_config=self.app_data.config,
+            force=self.app_data.encrypt_ignore_disk_space_error,
         )
         self.add_worker_actions(worker)
         self.threadpool.start(worker)
