@@ -9,7 +9,7 @@ from .component import (
     ToolBar,
     Action,
 )
-from .pyside import QtWidgets, QtCore, QtGui, QAction
+from .pyside import QtWidgets, QtCore, QtGui, QAction, open_window
 
 
 class FileSelectionWidget(QtWidgets.QGroupBox):
@@ -107,7 +107,7 @@ class FileSelectionWidget(QtWidgets.QGroupBox):
         if self.name_filter:
             dialog.setNameFilter(self.name_filter)
             dialog.selectNameFilter(self.name_filter)
-        if dialog.exec_() == QtWidgets.QDialog.Accepted:
+        if open_window(dialog) == QtWidgets.QDialog.Accepted:
             self._update_paths(dialog.selectedFiles())
 
 
@@ -137,22 +137,22 @@ class DirectoryAndFileSelectionWidget(FileSelectionWidget):
 
 
 class ArchiveOnlyFileSelectionWidget(FileSelectionWidget):
-    """File selection widget extension for selecting TAR archives only."""
+    """File selection widget extension for selecting ZIP and TAR archives only."""
 
     def __init__(self, label_text, parent):
-        super().__init__(label_text, parent, "Archives *.tar (*.tar)")
+        super().__init__(label_text, parent, "Archives (*.zip *.tar)")
 
     def dropEvent(self, event: QtGui.QDropEvent) -> None:
         paths = [
             url.toLocalFile()
             for url in event.mimeData().urls()
-            if url.toLocalFile().endswith(".tar")
+            if url.toLocalFile().endswith(".zip") or url.toLocalFile().endswith(".tar")
         ]
         if paths:
             self._update_paths(paths)
         else:
             show_warning(
                 APP_NAME_SHORT,
-                "Failed to load files. Only '.tar' archives are allowed.",
+                "Failed to load files. Only '.zip.' and '.tar' archives are allowed.",
                 self,
             )
