@@ -6,6 +6,7 @@ from sett.core.error import UserError
 from .component import SelectionAction, ToolBar, LineEdit, Action, warning_callback
 from .parallel import Worker
 from .pyside import QtCore, QtGui, QtWidgets, QAction, open_window
+from .keys_refresh import load_authority_key_threaded
 from ..core import crypt
 from ..core.crypt import gpg
 from ..utils.config import Config
@@ -20,9 +21,19 @@ class KeysTab(QtWidgets.QWidget):
         super().__init__(*args, **kwargs)
         self.threadpool = QtCore.QThreadPool.globalInstance()
         self.app_data = self.parent().app_data
+
+        # Update public and private key lists in AppData.
         self.update_private_keys()
         self.update_public_keys()
 
+        # At listeners that refresh the 'Keys' tab of the GUI to reflect
+        # changes in validation authority key.
+        for callback in (self.update_public_keys, self.update_display_selected_pub_key):
+            self.app_data.add_listener("validation_authority_key", callback)
+
+        # Download/refresh the validation authority key.
+        load_authority_key_threaded(self.app_data)
+
         self.text_panel = QtWidgets.QTextEdit()
         self.text_panel.setReadOnly(True)
 
@@ -39,7 +50,8 @@ class KeysTab(QtWidgets.QWidget):
             QtWidgets.QAbstractItemView.ExtendedSelection
         )
 
-        # When item is selected clear selection in the other list
+        # When item is selected in the public/private key list, clear
+        # the selection in the other list.
         self.priv_keys_view.selectionModel().currentChanged.connect(
             lambda: self.pub_keys_view.selectionModel().clear()
         )
@@ -62,9 +74,7 @@ class KeysTab(QtWidgets.QWidget):
             lambda: (
                 self.update_private_keys(),
                 self.update_public_keys(),
-                self._update_display(
-                    self.pub_keys_view.selectionModel().currentIndex()
-                ),
+                self.update_display_selected_pub_key(),
             )
         )
 
@@ -149,7 +159,7 @@ class KeysTab(QtWidgets.QWidget):
 
     @staticmethod
     def key_to_text(key: gpg.Key) -> str:
-        return f"User ID: {key.uids[0]}\n" f"Fingerprint: {key.fingerprint}"
+        return f"User ID: {key.uids[0]}\nFingerprint: {key.fingerprint}"
 
     def create_public_keys_actions(self) -> Iterator[QAction]:
         selection_model = self.pub_keys_view.selectionModel()
@@ -219,7 +229,7 @@ class KeysTab(QtWidgets.QWidget):
             yield action
 
     def update_private_keys(self):
-        # Retrieve all private keys from local keyring.
+        """Retrieve all private keys from the user's local keyring"""
         keys_private = self.app_data.config.gpg_store.list_sec_keys()
         try:
             default_key = (
@@ -239,14 +249,14 @@ class KeysTab(QtWidgets.QWidget):
         )
 
     def update_public_keys(self):
-        # Retrieve all public keys from local keyring.
+        """Retrieve all public keys from the user's local keyring"""
         keys_public = self.app_data.config.gpg_store.list_pub_keys(sigs=True)
         self.app_data.pub_keys_model.set_data(
             {f"{key.uids[0]} {key.key_id}": key for key in keys_public}
         )
 
     def update_keys(self):
-        """Updated selected keys from the keyserver."""
+        """Update/refresh selected keys from the keyserver"""
         show_ok = ok_message("Updated keys", "Keys have been successfully updated.")
         show_warning = warning_callback("GPG key update error")
 
@@ -264,17 +274,16 @@ class KeysTab(QtWidgets.QWidget):
                 forward_errors=show_warning,
             )
             worker.signals.result.connect(
-                lambda x: (
+                lambda: (
                     self.update_public_keys(),
-                    self._update_display(
-                        self.pub_keys_view.selectionModel().currentIndex()
-                    ),
+                    self.update_display_selected_pub_key(),
                     show_ok(),
                 )
             )
             self.threadpool.start(worker)
 
     def import_key(self):
+        """Import a GPG key from a local file"""
         path = QtWidgets.QFileDialog.getOpenFileName(
             self, "Select GPG key file", str(Path.home())
         )[0]
@@ -286,7 +295,7 @@ class KeysTab(QtWidgets.QWidget):
                     key_data = fin.read()
                 crypt.import_keys(key_data, self.app_data.config.gpg_store)
                 self.update_public_keys()
-                self._update_display(self.pub_keys_view.selectionModel().currentIndex())
+                self.update_display_selected_pub_key()
                 msg.setIcon(QtWidgets.QMessageBox.Information)
                 msg.setText("Key has been imported.")
                 open_window(msg)
@@ -378,6 +387,7 @@ class KeysTab(QtWidgets.QWidget):
         request_signature(selected_keys, self.app_data.config, self.threadpool, self)
 
     def _update_display(self, index: QtCore.QModelIndex):
+        """Display key info summary in GUI text panel"""
         style = (
             "<style>"
             "th {text-align: left; padding: 0 20px 5px 0;}"
@@ -393,12 +403,16 @@ class KeysTab(QtWidgets.QWidget):
             except IndexError:
                 self.text_panel.setHtml("")
 
+    def update_display_selected_pub_key(self):
+        """Refresh the displayed key info of the currently selected public key(s)"""
+        self._update_display(self.pub_keys_view.selectionModel().currentIndex())
+
 
 class KeyDownloadDialog(QtWidgets.QDialog):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.threadpool = QtCore.QThreadPool.globalInstance()
-        self.setWindowTitle("Download public keys from the server")
+        self.setWindowTitle("Download public keys from keyserver")
         self.setWindowFlags(self.windowFlags() & ~QtCore.Qt.WindowContextHelpButtonHint)
 
         self.search_string = LineEdit()
@@ -418,7 +432,7 @@ class KeyDownloadDialog(QtWidgets.QDialog):
         layout = QtWidgets.QGridLayout()
         layout.addWidget(
             QtWidgets.QLabel(
-                "Enter a search term (e.g. user name, email, key " "fingerprint)"
+                "Enter a search term (e.g. user name, email, key fingerprint)"
             ),
             0,
             0,
@@ -451,6 +465,7 @@ class KeyDownloadDialog(QtWidgets.QDialog):
         self.threadpool.start(worker)
 
     def download_selected(self):
+        """Download keys selected in the key-search pop-up to local keyring"""
         key_ids = []
         for index in self.key_list_view.selectedIndexes():
             key_ids.append(index.model().data(index).split()[-1])
@@ -465,7 +480,12 @@ class KeyDownloadDialog(QtWidgets.QDialog):
                 report_config=self.parent().app_data.config,
                 forward_errors=show_warning,
             )
-            worker.signals.result.connect(lambda x: self.parent().update_public_keys())
+            worker.signals.result.connect(
+                lambda: (
+                    self.parent().update_public_keys(),
+                    self.parent().update_display_selected_pub_key(),
+                )
+            )
             worker.signals.finished.connect(lambda: self.btn_download.setEnabled(True))
             self.threadpool.start(worker)
 
@@ -576,10 +596,16 @@ class KeyGenDialog(QtWidgets.QDialog):
     def create_private_key(self):
         show_warning = warning_callback("GPG Key Generation Error")
         self.btn_run.setEnabled(False)
-        full_name = f"{self.text_name_full.text()} " f"{self.text_name_extra.text()}"
+        name_full = self.text_name_full.text().strip()
+        name_extra = self.text_name_extra.text().strip()
+        if name_extra:
+            if not name_extra.startswith("(") and not name_extra.endswith(")"):
+                name_extra = f"({name_extra})"
+            name_full = name_full + " " + name_extra
+
         worker = Worker(
             crypt.create_key,
-            full_name,
+            name_full,
             self.text_email.text(),
             self.text_pass.text(),
             self.text_pass_repeat.text(),
@@ -604,6 +630,11 @@ def request_signature(
     threadpool: QtCore.QThreadPool,
     parent: Optional[QtWidgets.QWidget] = None,
 ):
+    """Request the specified keys to be signed by the key validation authority.
+    This triggers the following:
+     * The specified keys are uploaded to the keyserver.
+     * An email is sent to the key authority to request the signature.
+    """
     msg = QtWidgets.QMessageBox(parent)
     msg.setWindowTitle("Key signing request")
     msg.setText("Do you want to request signature for this key?")
