@@ -17,7 +17,6 @@ from .keys_tab import KeysTab
 from .model import AppData
 from .parallel import Worker
 from .pyside import QtCore, QtGui, QtWidgets, QAction, open_window
-from .keys_refresh import load_authority_key_threaded
 from .settings_tab import SettingsTab, config_to_settings
 from .transfer_tab import TransferTab
 from ..core.versioncheck import check_version
@@ -39,7 +38,6 @@ class MainWindow(QtWidgets.QMainWindow):
         self.add_tabs()
         self.add_status_bar()
         self.check_version()
-        load_authority_key_threaded(self.app_data)
 
     def get_config(self):
         with warnings.catch_warnings(record=True) as w:
@@ -173,11 +171,11 @@ class MainWindow(QtWidgets.QMainWindow):
 
 
 def open_url(url: str):
-    """Returns a function that will opens the specified URL in the user's
-    default browser when called. The function that is returned has no
-    arguments.
+    """Returns a function that will open the specified URL in the user's
+    default browser when called. The returned function has no arguments.
+
     :param url: URL to open.
-    :returns: function that opens specifed URL.
+    :returns: function that opens the specified URL.
     """
 
     def open_url_template():
