@@ -85,7 +85,6 @@ class SettingsTab(QtWidgets.QWidget):
 
     def _add_settings(self):
         encrypt_decrypt_group = self._add_group("Data encryption / decryption settings")
-
         self._add_widget_int_range(
             encrypt_decrypt_group,
             LABEL_COMPRESSION_LEVEL,
@@ -94,28 +93,24 @@ class SettingsTab(QtWidgets.QWidget):
             0,
             9,
         )
-
         self._add_widget_str(
             encrypt_decrypt_group,
             "Default sender",
             "default_sender",
             "Default sender fingerprint for encryption",
         )
-
         self._add_widget_bool(
             encrypt_decrypt_group,
             "Sign encrypted data",
             "sign_encrypted_data",
             "Whether encrypted data should be signed with sender's key",
         )
-
         self._add_widget_bool(
             encrypt_decrypt_group,
             "Always trust recipient key",
             "always_trust_recipient_key",
             "If unchecked, the encryption key must be signed by the local user",
         )
-
         self._add_widget_path(
             encrypt_decrypt_group,
             "Output directory",
@@ -123,7 +118,6 @@ class SettingsTab(QtWidgets.QWidget):
             "Default output directory, relevant for encryption/decryption",
             True,
         )
-
         self._add_widget_bool(
             encrypt_decrypt_group,
             "Offline mode",
@@ -131,7 +125,6 @@ class SettingsTab(QtWidgets.QWidget):
             "In offline mode, sett will not make any network connections: "
             "DTR verification and automatic PGP key downloading/updating is disabled.",
         )
-
         self._add_widget_str(
             encrypt_decrypt_group,
             "Default package suffix",
@@ -139,9 +132,7 @@ class SettingsTab(QtWidgets.QWidget):
             "Default suffix for encrypted package name",
             regex=PACKAGE_SUFFIX,
         )
-
         pgp_keys_group = self._add_group("PGP keys")
-
         self._add_widget_str(
             pgp_keys_group,
             "Key validation authority fingerprint",
@@ -150,7 +141,6 @@ class SettingsTab(QtWidgets.QWidget):
             "PGP key. If a value is specified, only keys signed the "
             "authority's key can be used.",
         )
-
         self._add_widget_path(
             pgp_keys_group,
             "GPG home directory",
@@ -159,7 +149,6 @@ class SettingsTab(QtWidgets.QWidget):
             "configuration files.",
             True,
         )
-
         # no validation, as specifying http:// is optional
         self._add_widget_str(
             pgp_keys_group,
@@ -167,16 +156,13 @@ class SettingsTab(QtWidgets.QWidget):
             "keyserver_url",
             "URL of the keyserver: used for publishing/fetching public PGP keys.",
         )
-
         data_transfer_group = self._add_group("Data transfer")
-
         self._add_widget_str(
             data_transfer_group,
             "SSH password encoding",
             "ssh_password_encoding",
             "Character encoding used for the SSH key password",
         )
-
         self._add_widget_str(
             data_transfer_group,
             "DCC portal URL",
@@ -185,9 +171,7 @@ class SettingsTab(QtWidgets.QWidget):
             "DTR (Data Transfer Request) validation.",
             REGEX_URL,
         )
-
         sett_updates_group = self._add_group("sett updates")
-
         self._add_widget_str(
             sett_updates_group,
             "Repo URL",
@@ -195,31 +179,19 @@ class SettingsTab(QtWidgets.QWidget):
             "Python package repository, used when looking for updates",
             REGEX_URL,
         )
-
         self._add_widget_bool(
             sett_updates_group,
             "Check version",
             "check_version",
             "Check whether you have the latest version of sett on startup",
         )
-
         misc_log_group = self._add_group("Miscellaneous and logs")
-
         self._add_widget_bool(
             misc_log_group,
             "Quit confirmation",
             "gui_quit_confirmation",
             "Ask for confirmation before closing the application",
         )
-
-        self._add_widget_path(
-            misc_log_group,
-            "Temp directory",
-            "temp_dir",
-            "Path to sett working directory",
-            True,
-        )
-
         self._add_widget_path(
             misc_log_group,
             "Log directory",
@@ -227,7 +199,6 @@ class SettingsTab(QtWidgets.QWidget):
             "Path to log files directory",
             True,
         )
-
         self._add_widget_int(
             misc_log_group,
             "Log max. file number",
@@ -235,7 +206,6 @@ class SettingsTab(QtWidgets.QWidget):
             "Maximum number of logfiles to keep as backup",
             1,
         )
-
         self._add_widget_bool(
             misc_log_group,
             "Create error reports",
