@@ -8,7 +8,7 @@ from .component import (
     TabMixin,
     PathInput,
     GuiProgress,
-    run_dialog,
+    get_text_input,
     MandatoryLabel,
     create_verify_dtr_checkbox,
     FieldMapping,
@@ -373,7 +373,7 @@ class TransferTab(QtWidgets.QWidget, TabMixin):
             nonlocal second_factor
             second_factor = None
             if msg == Msg.code:
-                output = run_dialog(self, "Verification code", password=False)
+                output = get_text_input(self, "Verification code", password=False)
                 second_factor = "" if output is None else output
 
         specific_protocol_args = {
