@@ -16,13 +16,15 @@ from ..core.archive import (
     extract_with_progress,
 )
 from ..core.crypt import (
+    check_password_matches_any_key,
     decrypt as core_decrypt,
+    enforce_passphrase,
     retrieve_refresh_and_validate_keys,
     fingerprint2keyid,
     verify_metadata_signature,
     gpg,
 )
-from ..core.filesystem import DeleteDirOnError, unique_filename
+from ..core.filesystem import DeleteDirOnError, unique_filename, check_space
 from ..core.checksum import (
     verify_checksums,
     compute_checksum_sha256,
@@ -66,6 +68,8 @@ def decrypt(
         for archive_path in files:
             check_package(archive_path)
 
+    check_space(files, output_dir, force=False)
+
     if dry_run:
         logger.info("Dry run completed successfully")
         return
@@ -115,19 +119,26 @@ def decrypt_archive(
         with logger.log_task("Verifying encryption keys..."), extract(
             archive_file, DATA_FILE_ENCRYPTED
         ) as f_data:
-            keys = retrieve_refresh_and_validate_keys(
-                key_search_terms=gpg.extract_key_id(f_data),
-                gpg_store=config.gpg_store,
-                key_authority_fingerprint=config.key_authority_fingerprint,
-                keyserver_url=config.keyserver_url,
+            keys = list(
+                retrieve_refresh_and_validate_keys(
+                    key_search_terms=gpg.extract_key_id(f_data),
+                    gpg_store=config.gpg_store,
+                    key_authority_fingerprint=config.key_authority_fingerprint,
+                    keyserver_url=config.keyserver_url,
+                )
             )
             logger.info(
                 "Data encrypted for:\n%s",
                 "\n".join(
-                    f"User ID    : {key.uids[0]}\n" f"Fingerprint: {key.fingerprint}"
+                    f"User ID    : {key.uids[0]}\nFingerprint: {key.fingerprint}"
                     for key in keys
                 ),
             )
+            check_password_matches_any_key(
+                password=enforce_passphrase(passphrase),
+                keys=keys,
+                gpg_store=config.gpg_store,
+            )
 
         with logger.log_task("Verifying checksums..."), subprogress(
             progress, step_completion_increase=0.05
