@@ -24,8 +24,10 @@ from ..core.filesystem import (
     delete_file_on_error,
     search_files_recursively,
     check_file_read_permission,
+    check_space,
 )
 from ..core.crypt import (
+    enforce_passphrase,
     retrieve_refresh_and_validate_keys,
     encrypt_and_sign,
     detach_sign_file,
@@ -76,19 +78,6 @@ def path_str(directory: bool = False, writable: bool = False) -> Callable:
 output_path_str = path_str(directory=True, writable=True)
 
 
-def check_arg_value(
-    arg_value: Union[str, int], arg_name: str, arg_type: Callable
-) -> None:
-    """Verify that the value of variable arg_value that is named arg_name is
-    following type arg_type. arg_type is a function that does a check
-    of the type of the variable.
-    """
-    try:
-        arg_type(arg_value)
-    except ValueError as e:
-        raise UserError(f"Invalid value for argument '{arg_name}': {e}") from e
-
-
 def check_integer_in_range(min_value: int, max_value: int) -> Callable:
     """Generate a function that will check that its input value is an integer,
     and that this integer is in the range [min_value:max_value].
@@ -125,6 +114,7 @@ def encrypt(
     dry_run: bool = False,
     offline: bool = False,
     verify_dtr: bool = True,
+    force: bool = False,
     compression_level: Optional[int] = None,
     purpose: Optional[Purpose] = None,
     progress: ProgressInterface = None,
@@ -160,15 +150,6 @@ def encrypt(
         )
         if dtr_id is None and verify_dtr:
             raise UserError("DTR (Data Transfer Request) ID is missing.")
-        if output:
-            check_arg_value(Path(output).name, "output name", output_name_str)
-            check_arg_value(
-                Path(output).as_posix()
-                if Path(output).is_dir()
-                else Path(output).parent.as_posix(),
-                "path in output name",
-                output_path_str,
-            )
         if output_suffix:
             check_arg_value(output_suffix, "output suffix", output_name_str)
 
@@ -208,40 +189,44 @@ def encrypt(
             ),
         )
 
-        project_code = determine_project_code(
-            dtr_id,
-            purpose,
-            config.portal_api if not offline and verify_dtr else None,
-            sender_pub_key,
-            recipients_pub_key,
-        )
+    project_code = determine_project_code(
+        dtr_id,
+        purpose,
+        config.portal_api if not offline and verify_dtr else None,
+        sender_pub_key,
+        recipients_pub_key,
+    )
 
-        timestamp = datetime.now().astimezone()
-        # The default value for the output name is based on date and time
-        # when the script is being run.
-        # Example output name is "20191011T145012".
-        output_name = generate_output_archive_name(
-            output,
-            default="_".join(
-                filter(
-                    None,
-                    [
-                        project_code,
-                        timestamp.strftime(DATE_FMT_FILENAME),
-                        output_suffix or config.package_name_suffix,
-                    ],
-                )
-            ),
-        )
+    timestamp = datetime.now().astimezone()
+    # The default value for the output name is based on date and time
+    # when the script is being run.
+    # Example output name is "20191011T145012".
+    output_name = generate_output_archive_name(
+        output,
+        default="_".join(
+            filter(
+                None,
+                [
+                    project_code,
+                    timestamp.strftime(DATE_FMT_FILENAME),
+                    output_suffix or config.package_name_suffix,
+                ],
+            )
+        ),
+    )
+    check_space(files_to_encrypt, os.path.dirname(output_name), force=force)
 
     if dry_run:
         logger.info("dry run completed successfully.")
         return None
 
-    # Check if gpg key password is correct
+    # If the user asked to sign the data, check that the GPG key password
+    # is correct.
     if config.sign_encrypted_data:
         check_password(
-            sender_pub_key.fingerprint, enforce_passphrase(passphrase), config.gpg_store
+            password=enforce_passphrase(passphrase),
+            key_fingerprint=sender_pub_key.fingerprint,
+            gpg_store=config.gpg_store,
         )
 
     archive_paths = [
@@ -349,6 +334,19 @@ def encrypt(
     return output_name
 
 
+def check_arg_value(
+    arg_value: Union[str, int], arg_name: str, arg_type: Callable
+) -> None:
+    """Verify that the value of variable arg_value that is named arg_name is
+    following type arg_type. arg_type is a function that does a check
+    of the type of the variable.
+    """
+    try:
+        arg_type(arg_value)
+    except ValueError as e:
+        raise UserError(f"Invalid value for argument '{arg_name}': {e}") from e
+
+
 def byte_encode_metadata(
     metadata: MetaData,
     gpg_store: gpg.GPGStore,
@@ -397,12 +395,6 @@ def determine_project_code(
     return project_code
 
 
-def enforce_passphrase(passphrase: Optional[Secret]) -> Secret:
-    if passphrase is None:
-        raise ValueError("No password given")
-    return passphrase
-
-
 def generate_output_archive_name(output_name: Optional[str], default: str) -> str:
     """Define the path + name of the output tarball file of the encrypt
     workflow. If output_name does not contain any path information, the
@@ -414,6 +406,16 @@ def generate_output_archive_name(output_name: Optional[str], default: str) -> st
     """
     if output_name is None:
         output_name = default
+    else:
+        check_arg_value(Path(output_name).name, "output name", output_name_str)
+        check_arg_value(
+            Path(output_name).as_posix()
+            if Path(output_name).is_dir()
+            else Path(output_name).parent.as_posix(),
+            "path in output name",
+            output_path_str,
+        )
+
     if Path(output_name).is_dir():
         output_name = os.path.join(output_name, default)
     # Add '.zip' extension to output name if needed.
